Crate defect_mcp

Crate defect_mcp 

MCP client adapter layer.

Wraps tools exposed by an external MCP server into a per-session tool table for defect_agent.

Structs

McpToolFactory
Minimal MCP factory.

Enums

McpAdapterError
MCP adapter errors.

Functions

registered_mcp_tool_name
Concatenates the MCP server name and upstream tool name into the tool name used for registration in the local ToolRegistry.